@@ -11,12 +11,12 @@ def scan(backend, timeout=10):
 
     Note: this must be run as root!
     """
-    result = []
-    for (mac, name) in backend.scan_for_devices(timeout):
+    return [
+        mac.upper()
+        for (mac, name) in backend.scan_for_devices(timeout)
         if (
             (name is not None and name.lower() in VALID_DEVICE_NAMES)
             or mac is not None
             and mac.upper().startswith(DEVICE_PREFIX)
-        ):
-            result.append(mac.upper())
-    return result
+        )
+    ]
